// Load data from CSV URL
d3.csv(
  'https://gist.githubusercontent.com/Yashwanth0402/2ed2bb635509e0c5589ea8d3fde39cb4/raw/3daf85546d68dc6b6c763e0e8ab0352297063f50/gistfile1.txt',
).then(function (data) {
  // Parse date and time, and convert year to number
  const parseDate = d3.timeParse('%Y');
  const parseTime = d3.timeParse('%H:%M');
  data.forEach((d) => {
    d.date = parseDate(d.date);
    d.time = parseTime(d.time);
  });

  // Extract cities from the data
  const cities = Object.keys(data[0]).filter(
    (key) => key !== 'date' && key !== 'time',
  );

  // Set up dimensions for the plot
  const margin = {
    top: 20,
    right: 30,
    bottom: 50,
    left: 50,
  };
  const width = 800 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  // Create SVG element
  const svg = d3
    .select('#scatter-plot')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Create scales
  const xScale = d3
    .scaleLinear()
    .domain([2010, 2020]) // Adjust domain based on your data
    .range([0, width]);

  const yScale = d3
    .scaleLinear()
    .domain([270, 310]) // Adjust domain based on your data
    .range([height, 0]);

  // Create colors scale for cities
  const colorScale = d3
    .scaleOrdinal()
    .domain(cities)
    .range(d3.schemeCategory10);

  // Function to update the scatter plot for a specific city
  function updatePlot(city) {
    // Update circles
    const circles = svg.selectAll('circle').data(data);

    circles
      .enter()
      .append('circle')
      .attr('cx', (d) => xScale(d.date.getFullYear()))
      .attr('cy', (d) => yScale(+d[city]))
      .attr('r', 4) // Circle size
      .attr('fill', colorScale(city));

    circles
      .attr('cx', (d) => xScale(d.date.getFullYear()))
      .attr('cy', (d) => yScale(+d[city]))
      .attr('fill', colorScale(city));

    circles.exit().remove();
  }

  // Initial plot update
  let currentIndex = 0;
  updatePlot(cities[currentIndex]);

  // Update plot for each city every 2 seconds
  setInterval(() => {
    currentIndex = (currentIndex + 1) % cities.length;
    updatePlot(cities[currentIndex]);
  }, 2000);

  // Create axis
  const xAxis = d3
    .axisBottom(xScale)
    .tickFormat(d3.format('d'));
  const yAxis = d3.axisLeft(yScale);

  // Add x-axis
  svg
    .append('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0, ${height})`)
    .call(xAxis);

  // Add y-axis
  svg.append('g').attr('class', 'y-axis').call(yAxis);

  // Add x-axis label
  svg
    .append('text')
    .attr('class', 'x-axis-label')
    .attr('x', width / 2)
    .attr('y', height + margin.top + 20)
    .style('text-anchor', 'middle')
    .text('Year');

  // Add y-axis label
  svg
    .append('text')
    .attr('class', 'y-axis-label')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -margin.left + 20)
    .style('text-anchor', 'middle')
    .text('Temperature (K)');
});
